package com.ruoyi.bid.mapper;

import java.util.List;
import com.ruoyi.bid.domain.BidMyZizhi;

/**
 * 资质管理Mapper接口
 * 
 * @author ruoyi
 * @date 2025-12-11
 */
public interface BidMyZizhiMapper 
{
    /**
     * 查询资质管理
     * 
     * @param id 资质管理主键
     * @return 资质管理
     */
    public BidMyZizhi selectBidMyZizhiById(Long id);

    /**
     * 查询资质管理列表
     * 
     * @param bidMyZizhi 资质管理
     * @return 资质管理集合
     */
    public List<BidMyZizhi> selectBidMyZizhiList(BidMyZizhi bidMyZizhi);

    /**
     * 新增资质管理
     * 
     * @param bidMyZizhi 资质管理
     * @return 结果
     */
    public int insertBidMyZizhi(BidMyZizhi bidMyZizhi);

    /**
     * 修改资质管理
     * 
     * @param bidMyZizhi 资质管理
     * @return 结果
     */
    public int updateBidMyZizhi(BidMyZizhi bidMyZizhi);

    /**
     * 删除资质管理
     * 
     * @param id 资质管理主键
     * @return 结果
     */
    public int deleteBidMyZizhiById(Long id);

    /**
     * 批量删除资质管理
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteBidMyZizhiByIds(Long[] ids);
}
